You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@beehive.apache.org by cs...@apache.org on 2006/01/16 21:30:09 UTC

svn commit: r369564 - in /beehive/trunk/system-controls: src/webservice/control/org/apache/beehive/controls/system/webservice/wsdl/ src/webservice/jaxrpc-clients/axis/org/apache/beehive/controls/system/jaxrpc/ test/webservice/webapp/src/complextypes/do...

Author: cschoett
Date: Mon Jan 16 12:29:41 2006
New Revision: 369564

URL: http://svn.apache.org/viewcvs?rev=369564&view=rev
Log:
Cleaned up the wsc DRT fault tests. Added a new fault test for rpc/enc/axisgen.

Added:
    beehive/trunk/system-controls/test/webservice/webapp/tests/org/apache/beehive/controls/system/webservice/units/rpcenc/axisgen/FaultsRpcEncAxisgenTest.java   (with props)
    beehive/trunk/system-controls/test/webservice/webapp/typesrc/complextypes/doclitwrapped/pojo/AccountException.java   (with props)
    beehive/trunk/system-controls/test/webservice/webapp/typesrc/complextypes/doclitwrapped/pojo/ComplexAccountException.java   (with props)
    beehive/trunk/system-controls/test/webservice/webapp/typesrc/complextypes/rpclit/pojo/AccountException.java   (with props)
    beehive/trunk/system-controls/test/webservice/webapp/typesrc/complextypes/rpclit/pojo/ComplexAccountException.java   (with props)
Modified:
    beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/wsdl/WsdlOpFaultList.java
    beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/wsdl/WsdlOpParameterList.java
    beehive/trunk/system-controls/src/webservice/jaxrpc-clients/axis/org/apache/beehive/controls/system/jaxrpc/AxisTypeRegistrar.java
    beehive/trunk/system-controls/test/webservice/webapp/src/complextypes/doclitwrapped/axisgen/ComplexTypesDocLitWrappedAxisgen.java
    beehive/trunk/system-controls/test/webservice/webapp/src/complextypes/doclitwrapped/pojo/ComplexTypesDocLitWrapped.java
    beehive/trunk/system-controls/test/webservice/webapp/src/complextypes/doclitwrapped/xmlbeangen/ComplexTypesDocLitWrappedXmlbeangen.java
    beehive/trunk/system-controls/test/webservice/webapp/src/complextypes/rpcenc/axisgen/ComplexTypesRpcEncAxisgen.java
    beehive/trunk/system-controls/test/webservice/webapp/src/complextypes/rpclit/axisgen/ComplexTypesRpcLitAxisgen.java
    beehive/trunk/system-controls/test/webservice/webapp/src/complextypes/rpclit/pojo/ComplexTypesRpcLit.java
    beehive/trunk/system-controls/test/webservice/webapp/src/complextypes/rpclit/xmlbeangen/ComplexTypesRpcLitXmlbeangen.java
    beehive/trunk/system-controls/test/webservice/webapp/src/org/apache/beehive/complextypes/AccountException.java
    beehive/trunk/system-controls/test/webservice/webapp/src/org/apache/beehive/complextypes/ComplexAccountException.java
    beehive/trunk/system-controls/test/webservice/webapp/src/org/apache/beehive/complextypes/ComplexTypes.java
    beehive/trunk/system-controls/test/webservice/webapp/tests/org/apache/beehive/controls/system/webservice/units/doclitwrapped/axisgen/FaultsDocLitWrappedAxisgenTest.java
    beehive/trunk/system-controls/test/webservice/webapp/tests/org/apache/beehive/controls/system/webservice/units/doclitwrapped/pojo/FaultsDocLitWrappedTest.java
    beehive/trunk/system-controls/test/webservice/webapp/tests/org/apache/beehive/controls/system/webservice/units/doclitwrapped/xmlbeangen/FaultsDocLitWrappedXmlbeangenTest.java
    beehive/trunk/system-controls/test/webservice/webapp/tests/org/apache/beehive/controls/system/webservice/units/rpclit/axisgen/FaultsRpcLitAxisgenTest.java
    beehive/trunk/system-controls/test/webservice/webapp/tests/org/apache/beehive/controls/system/webservice/units/rpclit/pojo/FaultsRpcLitTest.java
    beehive/trunk/system-controls/test/webservice/webapp/tests/org/apache/beehive/controls/system/webservice/units/rpclit/xmlbeangen/FaultsRpcLitXmlbeangenTest.java
    beehive/trunk/system-controls/test/webservice/webapp/wsdl/axisgen/ComplexTypesDocLitWrappedAxisgen.wsdl
    beehive/trunk/system-controls/test/webservice/webapp/wsdl/axisgen/ComplexTypesRpcEncAxisgen.wsdl
    beehive/trunk/system-controls/test/webservice/webapp/wsdl/axisgen/ComplexTypesRpcLitAxisgen.wsdl
    beehive/trunk/system-controls/test/webservice/webapp/wsdl/pojotypes/ComplexTypesDocLitWrapped.wsdl
    beehive/trunk/system-controls/test/webservice/webapp/wsdl/pojotypes/ComplexTypesRpcLit.wsdl
    beehive/trunk/system-controls/test/webservice/webapp/wsdl/xmlbeangen/ComplexTypesDocLitWrappedXmlbeangen.wsdl
    beehive/trunk/system-controls/test/webservice/webapp/wsdl/xmlbeangen/ComplexTypesRpcLitXmlbeangen.wsdl

Modified: beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/wsdl/WsdlOpFaultList.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/wsdl/WsdlOpFaultList.java?rev=369564&r1=369563&r2=369564&view=diff
==============================================================================
--- beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/wsdl/WsdlOpFaultList.java (original)
+++ beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/wsdl/WsdlOpFaultList.java Mon Jan 16 12:29:41 2006
@@ -28,6 +28,7 @@
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Map;
+import java.util.List;
 
 /**
  */
@@ -62,21 +63,24 @@
      * @return WsdlOpFault
      */
     private WsdlOpFault getFault(Fault fault) {
-
         Message m = fault.getMessage();
 
         // a fault should only have one message part.
         Map partMap = m.getParts();
         assert partMap.size() == 1 : "Invalid part count for fault!!";
         Part faultPart = (Part) partMap.values().iterator().next();
+        boolean complexType = false;
 
         // type of fault is specified either in Part's type or element attribute.
         QName type = faultPart.getTypeName();
         if (type == null) {
             type = faultPart.getElementName();
+            Element schemaElement = WsdlUtils.findSchemaElement(type, _wsdlDefinition);
+            assert schemaElement.hasAttribute("type");
+            type = _resolver.getTypeQName(schemaElement.getAttribute("type"));
+            complexType = true;
         }
-
-        return new WsdlOpFault(fault.getName(), type, hasComplexType(faultPart), _resolver);
+        return new WsdlOpFault(fault.getName(), type, complexType, _resolver);
     }
 
     /**
@@ -103,17 +107,5 @@
      */
     private WsdlOpFaultList(Collection<WsdlOpParameter> c) {
         this();
-    }
-
-    /**
-     * @param p
-     * @return true if part contains a complex type.
-     */
-    private boolean hasComplexType(Part p) {
-        if (p.getElementName() != null) {
-            Element schemaElement = WsdlUtils.findSchemaElement(p.getElementName(), _wsdlDefinition);
-            return !schemaElement.hasAttribute("type");
-        }
-        return false;
     }
 }

Modified: beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/wsdl/WsdlOpParameterList.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/wsdl/WsdlOpParameterList.java?rev=369564&r1=369563&r2=369564&view=diff
==============================================================================
--- beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/wsdl/WsdlOpParameterList.java (original)
+++ beehive/trunk/system-controls/src/webservice/control/org/apache/beehive/controls/system/webservice/wsdl/WsdlOpParameterList.java Mon Jan 16 12:29:41 2006
@@ -123,7 +123,7 @@
             if (WsdlUtils.isWrappedParameterStyle(_operation.getName(), !requesPart, part.getName())) {
                 _parameterStyle = WsdlOperation.SOAPParameterStyle.WRAPPED;
             }
-            params.addAll(unwrapPartElement(part));
+            params.addAll(resolvePartElement(part));
         }
         else {
             params.add(new WsdlOpParameter(part.getName(), part.getTypeName(),
@@ -235,24 +235,23 @@
      * @return A list of parameters resulting from the schema type -- typically the list will only
      *         contains a single parameter.
      */
-    private List<WsdlOpParameter> unwrapPartElement(Part p) {
+    private List<WsdlOpParameter> resolvePartElement(Part p) {
 
-        ArrayList<WsdlOpParameter> unwrappedParams = new ArrayList<WsdlOpParameter>();
+        ArrayList<WsdlOpParameter> resolvedParams = new ArrayList<WsdlOpParameter>();
         Element schemaElement = WsdlUtils.findSchemaElement(p.getElementName(), _wsdlDefinition);
 
         if (schemaElement.hasAttribute("type")) {
             // this is a simple type
-            unwrappedParams.add(new WsdlOpParameter(p.getName(), schemaElement, _resolver));
+            resolvedParams.add(new WsdlOpParameter(p.getName(), schemaElement, _resolver));
         }
         else {
             // this is a complex type
             Element complex = DomUtils.getChildElementByName(schemaElement, "complexType");
             Element sequence = DomUtils.getChildElementByName(complex, "sequence");
 
-            //todo: verify this block
             // may occaisionally find a <complex/> tag map to empty but this may be a bug in WSM
             if (sequence == null) {
-                return unwrappedParams;
+                return resolvedParams;
             }
 
             List<Element> seqElements = DomUtils.getChildElementsByName(sequence, "element");
@@ -265,9 +264,9 @@
                 if (op.isArray() && _parameterStyle == WsdlOperation.SOAPParameterStyle.BARE) {
                     op.setName(schemaElement.getAttribute("name"), _resolver);
                 }
-                unwrappedParams.add(op);
+                resolvedParams.add(op);
             }
         }
-        return unwrappedParams;
+        return resolvedParams;
     }
 }

Modified: beehive/trunk/system-controls/src/webservice/jaxrpc-clients/axis/org/apache/beehive/controls/system/jaxrpc/AxisTypeRegistrar.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/src/webservice/jaxrpc-clients/axis/org/apache/beehive/controls/system/jaxrpc/AxisTypeRegistrar.java?rev=369564&r1=369563&r2=369564&view=diff
==============================================================================
--- beehive/trunk/system-controls/src/webservice/jaxrpc-clients/axis/org/apache/beehive/controls/system/jaxrpc/AxisTypeRegistrar.java (original)
+++ beehive/trunk/system-controls/src/webservice/jaxrpc-clients/axis/org/apache/beehive/controls/system/jaxrpc/AxisTypeRegistrar.java Mon Jan 16 12:29:41 2006
@@ -137,6 +137,7 @@
 
     protected void registerClassAsXMLBeans(Class cls, QName q) {
         LOGGER.debug("Assigned XMLBeans Serialization to  class: " + cls.getCanonicalName() + " qname:" + q);
+        // todo: the XmlBeanSerializerFactory is available in Axis 1.2.1:1
         mTypeMapping.register(cls, q, new XmlBeanSerializerFactory(cls, q), new XmlBeanDeserializerFactory(cls, q));
     }
 

Modified: beehive/trunk/system-controls/test/webservice/webapp/src/complextypes/doclitwrapped/axisgen/ComplexTypesDocLitWrappedAxisgen.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/test/webservice/webapp/src/complextypes/doclitwrapped/axisgen/ComplexTypesDocLitWrappedAxisgen.java?rev=369564&r1=369563&r2=369564&view=diff
==============================================================================
--- beehive/trunk/system-controls/test/webservice/webapp/src/complextypes/doclitwrapped/axisgen/ComplexTypesDocLitWrappedAxisgen.java (original)
+++ beehive/trunk/system-controls/test/webservice/webapp/src/complextypes/doclitwrapped/axisgen/ComplexTypesDocLitWrappedAxisgen.java Mon Jan 16 12:29:41 2006
@@ -26,6 +26,7 @@
 import javax.jws.WebMethod;
 import javax.jws.WebService;
 import javax.jws.soap.SOAPBinding;
+import java.rmi.RemoteException;
 
 /**
  * doc/lit/wrapped service for testing axis generated types.
@@ -44,7 +45,7 @@
     }
 
     @WebMethod()
-    public int throwAccountException(int value) throws AccountException {
+    public int throwAccountException(int value) throws RemoteException {
         throw new AccountException("AccountException; input value=\"" + value + "\"");
     }
 

Modified: beehive/trunk/system-controls/test/webservice/webapp/src/complextypes/doclitwrapped/pojo/ComplexTypesDocLitWrapped.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/test/webservice/webapp/src/complextypes/doclitwrapped/pojo/ComplexTypesDocLitWrapped.java?rev=369564&r1=369563&r2=369564&view=diff
==============================================================================
--- beehive/trunk/system-controls/test/webservice/webapp/src/complextypes/doclitwrapped/pojo/ComplexTypesDocLitWrapped.java (original)
+++ beehive/trunk/system-controls/test/webservice/webapp/src/complextypes/doclitwrapped/pojo/ComplexTypesDocLitWrapped.java Mon Jan 16 12:29:41 2006
@@ -26,6 +26,7 @@
 import javax.jws.WebMethod;
 import javax.jws.WebService;
 import javax.jws.soap.SOAPBinding;
+import java.rmi.RemoteException;
 
 /**
  * doc/lit/wrapped service for testing non-generated java classes.
@@ -43,7 +44,7 @@
         return account;
     }
         @WebMethod()
-    public int throwAccountException(int value) throws AccountException {
+    public int throwAccountException(int value) throws RemoteException {
         throw new AccountException("AccountException; input value=\"" + value + "\"");
     }
 

Modified: beehive/trunk/system-controls/test/webservice/webapp/src/complextypes/doclitwrapped/xmlbeangen/ComplexTypesDocLitWrappedXmlbeangen.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/test/webservice/webapp/src/complextypes/doclitwrapped/xmlbeangen/ComplexTypesDocLitWrappedXmlbeangen.java?rev=369564&r1=369563&r2=369564&view=diff
==============================================================================
--- beehive/trunk/system-controls/test/webservice/webapp/src/complextypes/doclitwrapped/xmlbeangen/ComplexTypesDocLitWrappedXmlbeangen.java (original)
+++ beehive/trunk/system-controls/test/webservice/webapp/src/complextypes/doclitwrapped/xmlbeangen/ComplexTypesDocLitWrappedXmlbeangen.java Mon Jan 16 12:29:41 2006
@@ -26,6 +26,7 @@
 import javax.jws.WebMethod;
 import javax.jws.WebService;
 import javax.jws.soap.SOAPBinding;
+import java.rmi.RemoteException;
 
 /**
  * doc/lit/wrapped service for test xmlbean generated types.
@@ -44,7 +45,7 @@
     }
 
     @WebMethod()
-    public int throwAccountException(int value) throws AccountException {
+    public int throwAccountException(int value) throws RemoteException {
         throw new AccountException("AccountException; input value=\"" + value + "\"");
     }
 

Modified: beehive/trunk/system-controls/test/webservice/webapp/src/complextypes/rpcenc/axisgen/ComplexTypesRpcEncAxisgen.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/test/webservice/webapp/src/complextypes/rpcenc/axisgen/ComplexTypesRpcEncAxisgen.java?rev=369564&r1=369563&r2=369564&view=diff
==============================================================================
--- beehive/trunk/system-controls/test/webservice/webapp/src/complextypes/rpcenc/axisgen/ComplexTypesRpcEncAxisgen.java (original)
+++ beehive/trunk/system-controls/test/webservice/webapp/src/complextypes/rpcenc/axisgen/ComplexTypesRpcEncAxisgen.java Mon Jan 16 12:29:41 2006
@@ -20,10 +20,13 @@
 
 import org.apache.beehive.complextypes.BankAccount;
 import org.apache.beehive.complextypes.ComplexTypes;
+import org.apache.beehive.complextypes.ComplexAccountException;
+import org.apache.beehive.complextypes.AccountException;
 
 import javax.jws.WebMethod;
 import javax.jws.WebService;
 import javax.jws.soap.SOAPBinding;
+import java.rmi.RemoteException;
 
 
 /**
@@ -36,5 +39,15 @@
     @WebMethod
     public BankAccount echoAccount(BankAccount account) {
         return account;
+    }
+
+    @WebMethod
+    public int throwAccountException(int value) throws RemoteException {
+        throw new AccountException("AccountException; input value=\"" + value + "\"");
+    }
+
+    @WebMethod
+    public int throwComplexAccountException() throws ComplexAccountException {
+        throw new ComplexAccountException("FirstMessage", "SecondMessage");
     }
 }

Modified: beehive/trunk/system-controls/test/webservice/webapp/src/complextypes/rpclit/axisgen/ComplexTypesRpcLitAxisgen.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/test/webservice/webapp/src/complextypes/rpclit/axisgen/ComplexTypesRpcLitAxisgen.java?rev=369564&r1=369563&r2=369564&view=diff
==============================================================================
--- beehive/trunk/system-controls/test/webservice/webapp/src/complextypes/rpclit/axisgen/ComplexTypesRpcLitAxisgen.java (original)
+++ beehive/trunk/system-controls/test/webservice/webapp/src/complextypes/rpclit/axisgen/ComplexTypesRpcLitAxisgen.java Mon Jan 16 12:29:41 2006
@@ -26,6 +26,7 @@
 import javax.jws.WebMethod;
 import javax.jws.WebService;
 import javax.jws.soap.SOAPBinding;
+import java.rmi.RemoteException;
 
 /**
  * rpc literal service for testing axis generated types.
@@ -40,7 +41,7 @@
     }
 
     @WebMethod()
-    public int throwAccountException(int value) throws AccountException {
+    public int throwAccountException(int value) throws RemoteException {
         throw new AccountException("AccountException; input value=\"" + value + "\"");
     }
 

Modified: beehive/trunk/system-controls/test/webservice/webapp/src/complextypes/rpclit/pojo/ComplexTypesRpcLit.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/test/webservice/webapp/src/complextypes/rpclit/pojo/ComplexTypesRpcLit.java?rev=369564&r1=369563&r2=369564&view=diff
==============================================================================
--- beehive/trunk/system-controls/test/webservice/webapp/src/complextypes/rpclit/pojo/ComplexTypesRpcLit.java (original)
+++ beehive/trunk/system-controls/test/webservice/webapp/src/complextypes/rpclit/pojo/ComplexTypesRpcLit.java Mon Jan 16 12:29:41 2006
@@ -26,6 +26,7 @@
 import javax.jws.WebMethod;
 import javax.jws.WebService;
 import javax.jws.soap.SOAPBinding;
+import java.rmi.RemoteException;
 
 /**
  * rpc lit service for testing non-generated java types.
@@ -40,7 +41,7 @@
     }
 
     @WebMethod()
-    public int throwAccountException(int value) throws AccountException {
+    public int throwAccountException(int value) throws RemoteException {
         throw new AccountException("AccountException; input value=\"" + value + "\"");
     }
 

Modified: beehive/trunk/system-controls/test/webservice/webapp/src/complextypes/rpclit/xmlbeangen/ComplexTypesRpcLitXmlbeangen.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/test/webservice/webapp/src/complextypes/rpclit/xmlbeangen/ComplexTypesRpcLitXmlbeangen.java?rev=369564&r1=369563&r2=369564&view=diff
==============================================================================
--- beehive/trunk/system-controls/test/webservice/webapp/src/complextypes/rpclit/xmlbeangen/ComplexTypesRpcLitXmlbeangen.java (original)
+++ beehive/trunk/system-controls/test/webservice/webapp/src/complextypes/rpclit/xmlbeangen/ComplexTypesRpcLitXmlbeangen.java Mon Jan 16 12:29:41 2006
@@ -28,6 +28,8 @@
 import org.apache.beehive.complextypes.AccountException;
 import org.apache.beehive.complextypes.ComplexAccountException;
 
+import java.rmi.RemoteException;
+
 /**
  * rpc literal service for testing xmlbean generated types.
  */
@@ -41,7 +43,7 @@
     }
 
     @WebMethod()
-    public int throwAccountException(int value) throws AccountException {
+    public int throwAccountException(int value) throws RemoteException {
         throw new AccountException("AccountException; input value=\"" + value + "\"");
     }
 

Modified: beehive/trunk/system-controls/test/webservice/webapp/src/org/apache/beehive/complextypes/AccountException.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/test/webservice/webapp/src/org/apache/beehive/complextypes/AccountException.java?rev=369564&r1=369563&r2=369564&view=diff
==============================================================================
--- beehive/trunk/system-controls/test/webservice/webapp/src/org/apache/beehive/complextypes/AccountException.java (original)
+++ beehive/trunk/system-controls/test/webservice/webapp/src/org/apache/beehive/complextypes/AccountException.java Mon Jan 16 12:29:41 2006
@@ -17,13 +17,23 @@
  */
 package org.apache.beehive.complextypes;
 
+import java.rmi.RemoteException;
+
 /**
  * Simple exception for fault tests.
  */
-public class AccountException extends Exception implements java.io.Serializable {
+public class AccountException extends RemoteException implements java.io.Serializable {
 
     private static final long serialVersionUID = 1L;
 
-    public AccountException() { }
-    public AccountException(String msg) { super(msg); }
+    public AccountException() {
+    }
+
+    public AccountException(String msg) {
+        super(msg);
+    }
+
+    public AccountException(String msg, Throwable cause) {
+        super(msg, cause);
+    }
 }

Modified: beehive/trunk/system-controls/test/webservice/webapp/src/org/apache/beehive/complextypes/ComplexAccountException.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/test/webservice/webapp/src/org/apache/beehive/complextypes/ComplexAccountException.java?rev=369564&r1=369563&r2=369564&view=diff
==============================================================================
--- beehive/trunk/system-controls/test/webservice/webapp/src/org/apache/beehive/complextypes/ComplexAccountException.java (original)
+++ beehive/trunk/system-controls/test/webservice/webapp/src/org/apache/beehive/complextypes/ComplexAccountException.java Mon Jan 16 12:29:41 2006
@@ -38,7 +38,7 @@
     }
 
     public void setMsg2(String msg2) {
-        _msg1 = msg2;
+        _msg2 = msg2;
     }
 
     public String getMsg1() { return _msg1; }

Modified: beehive/trunk/system-controls/test/webservice/webapp/src/org/apache/beehive/complextypes/ComplexTypes.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/test/webservice/webapp/src/org/apache/beehive/complextypes/ComplexTypes.java?rev=369564&r1=369563&r2=369564&view=diff
==============================================================================
--- beehive/trunk/system-controls/test/webservice/webapp/src/org/apache/beehive/complextypes/ComplexTypes.java (original)
+++ beehive/trunk/system-controls/test/webservice/webapp/src/org/apache/beehive/complextypes/ComplexTypes.java Mon Jan 16 12:29:41 2006
@@ -18,8 +18,15 @@
 
 package org.apache.beehive.complextypes;
 
+import java.rmi.RemoteException;
+
 /**
  */
 public interface ComplexTypes {
+
     BankAccount echoAccount(BankAccount account);
+
+    public int throwAccountException(int value) throws RemoteException;
+
+    public int throwComplexAccountException() throws ComplexAccountException;
 }

Modified: beehive/trunk/system-controls/test/webservice/webapp/tests/org/apache/beehive/controls/system/webservice/units/doclitwrapped/axisgen/FaultsDocLitWrappedAxisgenTest.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/test/webservice/webapp/tests/org/apache/beehive/controls/system/webservice/units/doclitwrapped/axisgen/FaultsDocLitWrappedAxisgenTest.java?rev=369564&r1=369563&r2=369564&view=diff
==============================================================================
--- beehive/trunk/system-controls/test/webservice/webapp/tests/org/apache/beehive/controls/system/webservice/units/doclitwrapped/axisgen/FaultsDocLitWrappedAxisgenTest.java (original)
+++ beehive/trunk/system-controls/test/webservice/webapp/tests/org/apache/beehive/controls/system/webservice/units/doclitwrapped/axisgen/FaultsDocLitWrappedAxisgenTest.java Mon Jan 16 12:29:41 2006
@@ -17,72 +17,54 @@
  */
 package org.apache.beehive.controls.system.webservice.units.doclitwrapped.axisgen;
 
+import complextypes.doclitwrapped.axisgen.ComplexAccountException;
 import junit.framework.Test;
 import junit.framework.TestSuite;
 import org.apache.beehive.controls.api.bean.Control;
 import org.apache.beehive.controls.test.junit.ControlTestCase;
-import org.apache.axis.AxisFault;
-import org.w3c.dom.Element;
-import org.w3c.dom.NodeList;
-import org.w3c.dom.Node;
 
 /**
  * Tests for faults from a doc/lit/wrapped service.
  */
 public class FaultsDocLitWrappedAxisgenTest
-    extends ControlTestCase {
+        extends ControlTestCase {
 
     @Control
     public axisgentest.ComplexTypesDocLitWrappedAxisgenService client;
 
     /**
      * Test fault handling.
+     *
      * @throws Exception
      */
     public void testThrowAccountException() throws Exception {
-        assertTrue(true);
-        // todo: fails, needs further investigation
-        /*
         try {
             client.throwAccountException(66);
-        } catch (Exception e) {
-            assertEquals("org.apache.beehive.complextypes.AccountException: AccountException; input value=\"66\"", e.getMessage());
+        }
+        catch (Exception e) {
+            assertTrue("org.apache.beehive.complextypes.AccountException: AccountException; input value=\"66\"".equals(e.getMessage()));
             return;
         }
         fail("Expected AccountException to be thrown!");
-        */
     }
 
     /**
      * Test complex exception/fault handling.
+     *
      * @throws Exception
      */
     public void testThrowComplexAccountException() throws Exception {
-        assertTrue(true);
-        // todo: fails, needs further investigation
-        /*
         try {
             client.throwComplexAccountException();
-        } catch (Exception e) {
-            assertTrue(e instanceof AxisFault);
-            Element[] el = ((AxisFault)e).getFaultDetails();
-            assertNotNull(el);
-
-            NodeList children = el[0].getChildNodes();
-            assertTrue(children.getLength() == 2);
-
-            Node child = children.item(0);
-            assertEquals("msg1", child.getLocalName());
-            assertEquals("FirstMessage", child.getFirstChild().getNodeValue());
-
-            child = children.item(1);
-            assertEquals("msg2", child.getLocalName());
-            assertEquals("SecondMessage", child.getFirstChild().getNodeValue());
-
-             return;
+        }
+        catch (Exception e) {
+            assertTrue(e instanceof ComplexAccountException);
+            ComplexAccountException cae = (ComplexAccountException) e;
+            assertTrue("FirstMessage".equals(cae.getMsg1()));
+            assertTrue("SecondMessage".equals(cae.getMsg2()));
+            return;
         }
         fail("Expected ComplexAccountException to be thrown!");
-         */
     }
 
     public static Test suite() {

Modified: beehive/trunk/system-controls/test/webservice/webapp/tests/org/apache/beehive/controls/system/webservice/units/doclitwrapped/pojo/FaultsDocLitWrappedTest.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/test/webservice/webapp/tests/org/apache/beehive/controls/system/webservice/units/doclitwrapped/pojo/FaultsDocLitWrappedTest.java?rev=369564&r1=369563&r2=369564&view=diff
==============================================================================
--- beehive/trunk/system-controls/test/webservice/webapp/tests/org/apache/beehive/controls/system/webservice/units/doclitwrapped/xmlbeangen/FaultsDocLitWrappedXmlbeangenTest.java (original)
+++ beehive/trunk/system-controls/test/webservice/webapp/tests/org/apache/beehive/controls/system/webservice/units/doclitwrapped/xmlbeangen/FaultsDocLitWrappedXmlbeangenTest.java Mon Jan 16 12:29:41 2006
@@ -44,7 +44,7 @@
         try {
             client.throwAccountException(66);
         } catch (Exception e) {
-            assertEquals("org.apache.beehive.complextypes.AccountException: AccountException; input value=\"66\"", e.getMessage());
+            assertTrue("org.apache.beehive.complextypes.AccountException: AccountException; input value=\"66\"".equals(e.getMessage()));
             return;
         }
         fail("Expected AccountException to be thrown!");
@@ -60,18 +60,18 @@
         } catch (Exception e) {
             assertTrue(e instanceof AxisFault);
             Element[] el = ((AxisFault)e).getFaultDetails();
-            assertNotNull(el);
+            assertTrue(el != null);
 
             NodeList children = el[0].getChildNodes();
             assertTrue(children.getLength() == 2);
 
             Node child = children.item(0);
-            assertEquals("msg1", child.getLocalName());
-            assertEquals("FirstMessage", child.getFirstChild().getNodeValue());
+            assertTrue("msg1".equals(child.getLocalName()));
+            assertTrue("FirstMessage".equals(child.getFirstChild().getNodeValue()));
 
             child = children.item(1);
-            assertEquals("msg2", child.getLocalName());
-            assertEquals("SecondMessage", child.getFirstChild().getNodeValue());
+            assertTrue("msg2".equals(child.getLocalName()));
+            assertTrue("SecondMessage".equals(child.getFirstChild().getNodeValue()));
 
              return;
         }

Added: beehive/trunk/system-controls/test/webservice/webapp/tests/org/apache/beehive/controls/system/webservice/units/rpcenc/axisgen/FaultsRpcEncAxisgenTest.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/test/webservice/webapp/tests/org/apache/beehive/controls/system/webservice/units/rpcenc/axisgen/FaultsRpcEncAxisgenTest.java?rev=369564&view=auto
==============================================================================
--- beehive/trunk/system-controls/test/webservice/webapp/tests/org/apache/beehive/controls/system/webservice/units/rpcenc/axisgen/FaultsRpcEncAxisgenTest.java (added)
+++ beehive/trunk/system-controls/test/webservice/webapp/tests/org/apache/beehive/controls/system/webservice/units/rpcenc/axisgen/FaultsRpcEncAxisgenTest.java Mon Jan 16 12:29:41 2006
@@ -0,0 +1,79 @@
+/*
+ * Copyright 2005 The Apache Software Foundation.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ *
+ * $Header:$
+ */
+package org.apache.beehive.controls.system.webservice.units.rpcenc.axisgen;
+
+import junit.framework.Test;
+import junit.framework.TestSuite;
+import org.apache.axis.AxisFault;
+import org.apache.beehive.controls.api.bean.Control;
+import org.apache.beehive.controls.test.junit.ControlTestCase;
+import complextypes.rpcenc.axisgen.ComplexAccountException;
+
+/**
+ * Tests for faults from a rpc/lit service.
+ */
+public class FaultsRpcEncAxisgenTest
+        extends ControlTestCase {
+
+    @Control
+    public axisgentest.ComplexTypesRpcEncAxisgenService client;
+
+    /**
+     * Test fault handling.
+     *
+     * @throws Exception
+     */
+    public void testThrowAccountException() throws Exception {
+        try {
+            client.throwAccountException(66);
+        }
+        catch (Exception e) {
+            assertTrue(e instanceof AxisFault);
+            assertTrue("org.apache.beehive.complextypes.AccountException: AccountException; input value=\"66\"".equals(e.getMessage()));
+            return;
+        }
+        fail("Expected AccountException to be thrown!");
+    }
+
+    /**
+     * Test complex exception/fault handling.
+     *
+     * @throws Exception
+     */
+    public void testThrowComplexAccountException() throws Exception {
+        try {
+            client.throwComplexAccountException();
+        }
+        catch (Exception e) {
+            assertTrue(e instanceof ComplexAccountException);
+            ComplexAccountException cae = (ComplexAccountException) e;
+            assertTrue("FirstMessage".equals(cae.getMsg1()));
+            assertTrue("SecondMessage".equals(cae.getMsg2()));
+            return;
+        }
+        fail("Expected ComplexAccountException to be thrown!");
+    }
+
+    public static Test suite() {
+        return new TestSuite(FaultsRpcEncAxisgenTest.class);
+    }
+
+    public static void main(String[] args) {
+        junit.textui.TestRunner.run(suite());
+    }
+}
\ No newline at end of file

Propchange: beehive/trunk/system-controls/test/webservice/webapp/tests/org/apache/beehive/controls/system/webservice/units/rpcenc/axisgen/FaultsRpcEncAxisgenTest.java
------------------------------------------------------------------------------
    svn:eol-style = native

Modified: beehive/trunk/system-controls/test/webservice/webapp/tests/org/apache/beehive/controls/system/webservice/units/rpclit/axisgen/FaultsRpcLitAxisgenTest.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/test/webservice/webapp/tests/org/apache/beehive/controls/system/webservice/units/rpclit/axisgen/FaultsRpcLitAxisgenTest.java?rev=369564&r1=369563&r2=369564&view=diff
==============================================================================
--- beehive/trunk/system-controls/test/webservice/webapp/tests/org/apache/beehive/controls/system/webservice/units/rpclit/axisgen/FaultsRpcLitAxisgenTest.java (original)
+++ beehive/trunk/system-controls/test/webservice/webapp/tests/org/apache/beehive/controls/system/webservice/units/rpclit/axisgen/FaultsRpcLitAxisgenTest.java Mon Jan 16 12:29:41 2006
@@ -19,31 +19,34 @@
 
 import junit.framework.Test;
 import junit.framework.TestSuite;
+import org.apache.axis.AxisFault;
 import org.apache.beehive.controls.api.bean.Control;
 import org.apache.beehive.controls.test.junit.ControlTestCase;
-import org.apache.axis.AxisFault;
 import org.w3c.dom.Element;
-import org.w3c.dom.NodeList;
 import org.w3c.dom.Node;
+import org.w3c.dom.NodeList;
 
 /**
  * Tests for faults from a rpc/lit service.
  */
 public class FaultsRpcLitAxisgenTest
-    extends ControlTestCase {
+        extends ControlTestCase {
 
     @Control
     public axisgentest.ComplexTypesRpcLitAxisgenService client;
 
     /**
      * Test fault handling.
+     *
      * @throws Exception
      */
     public void testThrowAccountException() throws Exception {
         try {
             client.throwAccountException(66);
-        } catch (Exception e) {
-            assertEquals("org.apache.beehive.complextypes.AccountException: AccountException; input value=\"66\"", e.getMessage());
+        }
+        catch (Exception e) {
+            assertTrue(e instanceof AxisFault);
+            assertTrue("org.apache.beehive.complextypes.AccountException: AccountException; input value=\"66\"".equals(e.getMessage()));
             return;
         }
         fail("Expected AccountException to be thrown!");
@@ -51,28 +54,28 @@
 
     /**
      * Test complex exception/fault handling.
+     *
      * @throws Exception
      */
     public void testThrowComplexAccountException() throws Exception {
         try {
             client.throwComplexAccountException();
-        } catch (Exception e) {
+        }
+        catch (Exception e) {
             assertTrue(e instanceof AxisFault);
-            Element[] el = ((AxisFault)e).getFaultDetails();
-            assertNotNull(el);
-
+            Element[] el = ((AxisFault) e).getFaultDetails();
+            assertTrue(el != null);
             NodeList children = el[0].getChildNodes();
             assertTrue(children.getLength() == 2);
 
             Node child = children.item(0);
-            assertEquals("msg1", child.getLocalName());
-            assertEquals("FirstMessage", child.getFirstChild().getNodeValue());
+            assertTrue("msg1".equals(child.getLocalName()));
+            assertTrue("FirstMessage".equals(child.getFirstChild().getNodeValue()));
 
             child = children.item(1);
-            assertEquals("msg2", child.getLocalName());
-            assertEquals("SecondMessage", child.getFirstChild().getNodeValue());
-
-             return;
+            assertTrue("msg2".equals(child.getLocalName()));
+            assertTrue("SecondMessage".equals(child.getFirstChild().getNodeValue()));
+            return;
         }
         fail("Expected ComplexAccountException to be thrown!");
     }

Modified: beehive/trunk/system-controls/test/webservice/webapp/tests/org/apache/beehive/controls/system/webservice/units/rpclit/pojo/FaultsRpcLitTest.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/test/webservice/webapp/tests/org/apache/beehive/controls/system/webservice/units/rpclit/pojo/FaultsRpcLitTest.java?rev=369564&r1=369563&r2=369564&view=diff
==============================================================================
--- beehive/trunk/system-controls/test/webservice/webapp/tests/org/apache/beehive/controls/system/webservice/units/rpclit/pojo/FaultsRpcLitTest.java (original)
+++ beehive/trunk/system-controls/test/webservice/webapp/tests/org/apache/beehive/controls/system/webservice/units/rpclit/pojo/FaultsRpcLitTest.java Mon Jan 16 12:29:41 2006
@@ -43,7 +43,8 @@
         try {
             client.throwAccountException(66);
         } catch (Exception e) {
-            assertEquals("org.apache.beehive.complextypes.AccountException: AccountException; input value=\"66\"", e.getMessage());
+            assertTrue(e instanceof AxisFault);
+            assertTrue("org.apache.beehive.complextypes.AccountException: AccountException; input value=\"66\"".equals(e.getMessage()));
             return;
         }
         fail("Expected AccountException to be thrown!");
@@ -59,18 +60,18 @@
         } catch (Exception e) {
             assertTrue(e instanceof AxisFault);
             Element[] el = ((AxisFault)e).getFaultDetails();
-            assertNotNull(el);
+            assertTrue(el != null);
 
             NodeList children = el[0].getChildNodes();
             assertTrue(children.getLength() == 2);
 
             Node child = children.item(0);
-            assertEquals("msg1", child.getLocalName());
-            assertEquals("FirstMessage", child.getFirstChild().getNodeValue());
+            assertTrue("msg1".equals(child.getLocalName()));
+            assertTrue("FirstMessage".equals(child.getFirstChild().getNodeValue()));
 
             child = children.item(1);
-            assertEquals("msg2", child.getLocalName());
-            assertEquals("SecondMessage", child.getFirstChild().getNodeValue());
+            assertTrue("msg2".equals(child.getLocalName()));
+            assertTrue("SecondMessage".equals(child.getFirstChild().getNodeValue()));
 
              return;
         }

Modified: beehive/trunk/system-controls/test/webservice/webapp/tests/org/apache/beehive/controls/system/webservice/units/rpclit/xmlbeangen/FaultsRpcLitXmlbeangenTest.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/test/webservice/webapp/tests/org/apache/beehive/controls/system/webservice/units/rpclit/xmlbeangen/FaultsRpcLitXmlbeangenTest.java?rev=369564&r1=369563&r2=369564&view=diff
==============================================================================
--- beehive/trunk/system-controls/test/webservice/webapp/tests/org/apache/beehive/controls/system/webservice/units/rpclit/xmlbeangen/FaultsRpcLitXmlbeangenTest.java (original)
+++ beehive/trunk/system-controls/test/webservice/webapp/tests/org/apache/beehive/controls/system/webservice/units/rpclit/xmlbeangen/FaultsRpcLitXmlbeangenTest.java Mon Jan 16 12:29:41 2006
@@ -45,7 +45,8 @@
         try {
             client.throwAccountException(66);
         } catch (Exception e) {
-            assertEquals("org.apache.beehive.complextypes.AccountException: AccountException; input value=\"66\"", e.getMessage());
+            assertTrue(e instanceof AxisFault);
+            assertTrue("org.apache.beehive.complextypes.AccountException: AccountException; input value=\"66\"".equals(e.getMessage()));
             return;
         }
         fail("Expected AccountException to be thrown!");
@@ -61,19 +62,18 @@
         } catch (Exception e) {
             assertTrue(e instanceof AxisFault);
             Element[] el = ((AxisFault)e).getFaultDetails();
-            assertNotNull(el);
+            assertTrue(el != null);
 
             NodeList children = el[0].getChildNodes();
             assertTrue(children.getLength() == 2);
 
             Node child = children.item(0);
-            assertEquals("msg1", child.getLocalName());
-            assertEquals("FirstMessage", child.getFirstChild().getNodeValue());
+            assertTrue("msg1".equals(child.getLocalName()));
+            assertTrue("FirstMessage".equals(child.getFirstChild().getNodeValue()));
 
             child = children.item(1);
-            assertEquals("msg2", child.getLocalName());
-            assertEquals("SecondMessage", child.getFirstChild().getNodeValue());
-
+            assertTrue("msg2".equals(child.getLocalName()));
+            assertTrue("SecondMessage".equals(child.getFirstChild().getNodeValue()));
              return;
         }
         fail("Expected ComplexAccountException to be thrown!");

Added: beehive/trunk/system-controls/test/webservice/webapp/typesrc/complextypes/doclitwrapped/pojo/AccountException.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/test/webservice/webapp/typesrc/complextypes/doclitwrapped/pojo/AccountException.java?rev=369564&view=auto
==============================================================================
--- beehive/trunk/system-controls/test/webservice/webapp/typesrc/complextypes/doclitwrapped/pojo/AccountException.java (added)
+++ beehive/trunk/system-controls/test/webservice/webapp/typesrc/complextypes/doclitwrapped/pojo/AccountException.java Mon Jan 16 12:29:41 2006
@@ -0,0 +1,39 @@
+/*
+ * Copyright 2004-2005 The Apache Software Foundation
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ *
+ * $Header:$
+ */
+package complextypes.doclitwrapped.pojo;
+
+import java.rmi.RemoteException;
+
+/**
+ * Simple exception for fault tests.
+ */
+public class AccountException extends RemoteException implements java.io.Serializable {
+
+    private static final long serialVersionUID = 1L;
+
+    public AccountException() {
+    }
+
+    public AccountException(String msg) {
+        super(msg);
+    }
+
+    public AccountException(String msg, Throwable cause) {
+        super(msg, cause);
+    }
+}

Propchange: beehive/trunk/system-controls/test/webservice/webapp/typesrc/complextypes/doclitwrapped/pojo/AccountException.java
------------------------------------------------------------------------------
    svn:eol-style = native

Added: beehive/trunk/system-controls/test/webservice/webapp/typesrc/complextypes/doclitwrapped/pojo/ComplexAccountException.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/test/webservice/webapp/typesrc/complextypes/doclitwrapped/pojo/ComplexAccountException.java?rev=369564&view=auto
==============================================================================
--- beehive/trunk/system-controls/test/webservice/webapp/typesrc/complextypes/doclitwrapped/pojo/ComplexAccountException.java (added)
+++ beehive/trunk/system-controls/test/webservice/webapp/typesrc/complextypes/doclitwrapped/pojo/ComplexAccountException.java Mon Jan 16 12:29:41 2006
@@ -0,0 +1,53 @@
+/*
+ * Copyright 2004-2005 The Apache Software Foundation
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ *
+ * $Header:$
+ */
+package complextypes.doclitwrapped.pojo;
+
+
+/**
+ * Complex exception for fault testing.
+ */
+public class ComplexAccountException extends Exception implements java.io.Serializable {
+
+    private static final long serialVersionUID = 1L;
+    private String _msg1;
+    private String _msg2;
+
+    public ComplexAccountException() {
+    }
+
+    public ComplexAccountException(String msg1, String msg2) {
+        _msg1 = msg1;
+        _msg2 = msg2;
+    }
+
+    public void setMsg1(String msg1) {
+        _msg1 = msg1;
+    }
+
+    public void setMsg2(String msg2) {
+        _msg2 = msg2;
+    }
+
+    public String getMsg1() {
+        return _msg1;
+    }
+
+    public String getMsg2() {
+        return _msg2;
+    }
+}

Propchange: beehive/trunk/system-controls/test/webservice/webapp/typesrc/complextypes/doclitwrapped/pojo/ComplexAccountException.java
------------------------------------------------------------------------------
    svn:eol-style = native

Added: beehive/trunk/system-controls/test/webservice/webapp/typesrc/complextypes/rpclit/pojo/AccountException.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/test/webservice/webapp/typesrc/complextypes/rpclit/pojo/AccountException.java?rev=369564&view=auto
==============================================================================
--- beehive/trunk/system-controls/test/webservice/webapp/typesrc/complextypes/rpclit/pojo/AccountException.java (added)
+++ beehive/trunk/system-controls/test/webservice/webapp/typesrc/complextypes/rpclit/pojo/AccountException.java Mon Jan 16 12:29:41 2006
@@ -0,0 +1,39 @@
+/*
+ * Copyright 2004-2005 The Apache Software Foundation
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ *
+ * $Header:$
+ */
+package complextypes.rpclit.pojo;
+
+import java.rmi.RemoteException;
+
+/**
+ * Simple exception for fault tests.
+ */
+public class AccountException extends RemoteException implements java.io.Serializable {
+
+    private static final long serialVersionUID = 1L;
+
+    public AccountException() {
+    }
+
+    public AccountException(String msg) {
+        super(msg);
+    }
+
+    public AccountException(String msg, Throwable cause) {
+        super(msg, cause);
+    }
+}

Propchange: beehive/trunk/system-controls/test/webservice/webapp/typesrc/complextypes/rpclit/pojo/AccountException.java
------------------------------------------------------------------------------
    svn:eol-style = native

Added: beehive/trunk/system-controls/test/webservice/webapp/typesrc/complextypes/rpclit/pojo/ComplexAccountException.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/test/webservice/webapp/typesrc/complextypes/rpclit/pojo/ComplexAccountException.java?rev=369564&view=auto
==============================================================================
--- beehive/trunk/system-controls/test/webservice/webapp/typesrc/complextypes/rpclit/pojo/ComplexAccountException.java (added)
+++ beehive/trunk/system-controls/test/webservice/webapp/typesrc/complextypes/rpclit/pojo/ComplexAccountException.java Mon Jan 16 12:29:41 2006
@@ -0,0 +1,53 @@
+/*
+ * Copyright 2004-2005 The Apache Software Foundation
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ *
+ * $Header:$
+ */
+package complextypes.rpclit.pojo;
+
+
+/**
+ * Complex exception for fault testing.
+ */
+public class ComplexAccountException extends Exception implements java.io.Serializable {
+
+    private static final long serialVersionUID = 1L;
+    private String _msg1;
+    private String _msg2;
+
+    public ComplexAccountException() {
+    }
+
+    public ComplexAccountException(String msg1, String msg2) {
+        _msg1 = msg1;
+        _msg2 = msg2;
+    }
+
+    public void setMsg1(String msg1) {
+        _msg1 = msg1;
+    }
+
+    public void setMsg2(String msg2) {
+        _msg2 = msg2;
+    }
+
+    public String getMsg1() {
+        return _msg1;
+    }
+
+    public String getMsg2() {
+        return _msg2;
+    }
+}

Propchange: beehive/trunk/system-controls/test/webservice/webapp/typesrc/complextypes/rpclit/pojo/ComplexAccountException.java
------------------------------------------------------------------------------
    svn:eol-style = native

Modified: beehive/trunk/system-controls/test/webservice/webapp/wsdl/axisgen/ComplexTypesDocLitWrappedAxisgen.wsdl
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/test/webservice/webapp/wsdl/axisgen/ComplexTypesDocLitWrappedAxisgen.wsdl?rev=369564&r1=369563&r2=369564&view=diff
==============================================================================
--- beehive/trunk/system-controls/test/webservice/webapp/wsdl/axisgen/ComplexTypesDocLitWrappedAxisgen.wsdl (original)
+++ beehive/trunk/system-controls/test/webservice/webapp/wsdl/axisgen/ComplexTypesDocLitWrappedAxisgen.wsdl Mon Jan 16 12:29:41 2006
@@ -52,10 +52,6 @@
      </sequence>
     </complexType>
    </element>
-   <complexType name="AccountException">
-    <sequence/>
-   </complexType>
-   <element name="fault" type="impl:AccountException"/>
    <element name="throwComplexAccountException">
     <complexType/>
    </element>
@@ -72,13 +68,13 @@
      <element name="msg2" nillable="true" type="xsd:string"/>
     </sequence>
    </complexType>
-   <element name="fault1" type="impl:ComplexAccountException"/>
+   <element name="fault" type="impl:ComplexAccountException"/>
   </schema>
  </wsdl:types>
 
    <wsdl:message name="ComplexAccountException">
 
-      <wsdl:part element="impl:fault1" name="fault"/>
+      <wsdl:part element="impl:fault" name="fault"/>
 
    </wsdl:message>
 
@@ -112,12 +108,6 @@
 
    </wsdl:message>
 
-   <wsdl:message name="AccountException">
-
-      <wsdl:part element="impl:fault" name="fault"/>
-
-   </wsdl:message>
-
    <wsdl:message name="echoAccountRequest">
 
       <wsdl:part element="impl:echoAccount" name="parameters"/>
@@ -140,8 +130,6 @@
 
          <wsdl:output message="impl:throwAccountExceptionResponse" name="throwAccountExceptionResponse"/>
 
-         <wsdl:fault message="impl:AccountException" name="AccountException"/>
-
       </wsdl:operation>
 
       <wsdl:operation name="throwComplexAccountException">
@@ -193,12 +181,6 @@
             <wsdlsoap:body use="literal"/>
 
          </wsdl:output>
-
-         <wsdl:fault name="AccountException">
-
-            <wsdlsoap:fault name="AccountException" use="literal"/>
-
-         </wsdl:fault>
 
       </wsdl:operation>
 

Modified: beehive/trunk/system-controls/test/webservice/webapp/wsdl/axisgen/ComplexTypesRpcEncAxisgen.wsdl
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/test/webservice/webapp/wsdl/axisgen/ComplexTypesRpcEncAxisgen.wsdl?rev=369564&r1=369563&r2=369564&view=diff
==============================================================================
--- beehive/trunk/system-controls/test/webservice/webapp/wsdl/axisgen/ComplexTypesRpcEncAxisgen.wsdl (original)
+++ beehive/trunk/system-controls/test/webservice/webapp/wsdl/axisgen/ComplexTypesRpcEncAxisgen.wsdl Mon Jan 16 12:29:41 2006
@@ -27,9 +27,39 @@
      <element name="transactions" nillable="true" type="impl:AccountTransaction[]"/>
     </sequence>
    </complexType>
+   <complexType name="ComplexAccountException">
+    <sequence>
+     <element name="msg1" nillable="true" type="soapenc:string"/>
+     <element name="msg2" nillable="true" type="soapenc:string"/>
+    </sequence>
+   </complexType>
   </schema>
  </wsdl:types>
 
+   <wsdl:message name="throwAccountExceptionRequest">
+
+      <wsdl:part name="value" type="xsd:int"/>
+
+   </wsdl:message>
+
+   <wsdl:message name="throwComplexAccountExceptionResponse">
+
+      <wsdl:part name="return" type="xsd:int"/>
+
+   </wsdl:message>
+
+   <wsdl:message name="throwAccountExceptionResponse">
+
+      <wsdl:part name="return" type="xsd:int"/>
+
+   </wsdl:message>
+
+   <wsdl:message name="ComplexAccountException">
+
+      <wsdl:part name="fault" type="impl:ComplexAccountException"/>
+
+   </wsdl:message>
+
    <wsdl:message name="echoAccountResponse">
 
       <wsdl:part name="return" type="impl:BankAccount"/>
@@ -42,6 +72,10 @@
 
    </wsdl:message>
 
+   <wsdl:message name="throwComplexAccountExceptionRequest">
+
+   </wsdl:message>
+
    <wsdl:portType name="ComplexTypesRpcEncAxisgen">
 
       <wsdl:operation name="echoAccount" parameterOrder="account">
@@ -52,6 +86,24 @@
 
       </wsdl:operation>
 
+      <wsdl:operation name="throwAccountException" parameterOrder="value">
+
+         <wsdl:input message="impl:throwAccountExceptionRequest" name="throwAccountExceptionRequest"/>
+
+         <wsdl:output message="impl:throwAccountExceptionResponse" name="throwAccountExceptionResponse"/>
+
+      </wsdl:operation>
+
+      <wsdl:operation name="throwComplexAccountException">
+
+         <wsdl:input message="impl:throwComplexAccountExceptionRequest" name="throwComplexAccountExceptionRequest"/>
+
+         <wsdl:output message="impl:throwComplexAccountExceptionResponse" name="throwComplexAccountExceptionResponse"/>
+
+         <wsdl:fault message="impl:ComplexAccountException" name="ComplexAccountException"/>
+
+      </wsdl:operation>
+
    </wsdl:portType>
 
    <wsdl:binding name="ComplexTypesRpcEncAxisgenSoapBinding" type="impl:ComplexTypesRpcEncAxisgen">
@@ -73,6 +125,48 @@
             <wsdlsoap:body encodingStyle="http://schemas.xmlsoap.org/soap/encoding/" namespace="http://axisgen.rpcenc.complextypes" use="encoded"/>
 
          </wsdl:output>
+
+      </wsdl:operation>
+
+      <wsdl:operation name="throwAccountException">
+
+         <wsdlsoap:operation soapAction=""/>
+
+         <wsdl:input name="throwAccountExceptionRequest">
+
+            <wsdlsoap:body encodingStyle="http://schemas.xmlsoap.org/soap/encoding/" namespace="http://axisgen.rpcenc.complextypes" use="encoded"/>
+
+         </wsdl:input>
+
+         <wsdl:output name="throwAccountExceptionResponse">
+
+            <wsdlsoap:body encodingStyle="http://schemas.xmlsoap.org/soap/encoding/" namespace="http://axisgen.rpcenc.complextypes" use="encoded"/>
+
+         </wsdl:output>
+
+      </wsdl:operation>
+
+      <wsdl:operation name="throwComplexAccountException">
+
+         <wsdlsoap:operation soapAction=""/>
+
+         <wsdl:input name="throwComplexAccountExceptionRequest">
+
+            <wsdlsoap:body encodingStyle="http://schemas.xmlsoap.org/soap/encoding/" namespace="http://axisgen.rpcenc.complextypes" use="encoded"/>
+
+         </wsdl:input>
+
+         <wsdl:output name="throwComplexAccountExceptionResponse">
+
+            <wsdlsoap:body encodingStyle="http://schemas.xmlsoap.org/soap/encoding/" namespace="http://axisgen.rpcenc.complextypes" use="encoded"/>
+
+         </wsdl:output>
+
+         <wsdl:fault name="ComplexAccountException">
+
+            <wsdlsoap:fault encodingStyle="http://schemas.xmlsoap.org/soap/encoding/" name="ComplexAccountException" namespace="http://axisgen.rpcenc.complextypes" use="encoded"/>
+
+         </wsdl:fault>
 
       </wsdl:operation>
 

Modified: beehive/trunk/system-controls/test/webservice/webapp/wsdl/axisgen/ComplexTypesRpcLitAxisgen.wsdl
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/test/webservice/webapp/wsdl/axisgen/ComplexTypesRpcLitAxisgen.wsdl?rev=369564&r1=369563&r2=369564&view=diff
==============================================================================
--- beehive/trunk/system-controls/test/webservice/webapp/wsdl/axisgen/ComplexTypesRpcLitAxisgen.wsdl (original)
+++ beehive/trunk/system-controls/test/webservice/webapp/wsdl/axisgen/ComplexTypesRpcLitAxisgen.wsdl Mon Jan 16 12:29:41 2006
@@ -25,9 +25,6 @@
      <element name="transactions" nillable="true" type="impl:ArrayOfAccountTransaction"/>
     </sequence>
    </complexType>
-   <complexType name="AccountException">
-    <sequence/>
-   </complexType>
    <complexType name="ComplexAccountException">
     <sequence>
      <element name="msg1" nillable="true" type="xsd:string"/>
@@ -43,12 +40,6 @@
 
    </wsdl:message>
 
-   <wsdl:message name="AccountException">
-
-      <wsdl:part name="fault" type="impl:AccountException"/>
-
-   </wsdl:message>
-
    <wsdl:message name="ComplexAccountException">
 
       <wsdl:part name="fault" type="impl:ComplexAccountException"/>
@@ -99,8 +90,6 @@
 
          <wsdl:output message="impl:throwAccountExceptionResponse" name="throwAccountExceptionResponse"/>
 
-         <wsdl:fault message="impl:AccountException" name="AccountException"/>
-
       </wsdl:operation>
 
       <wsdl:operation name="throwComplexAccountException">
@@ -152,12 +141,6 @@
             <wsdlsoap:body namespace="http://axisgen.rpclit.complextypes" use="literal"/>
 
          </wsdl:output>
-
-         <wsdl:fault name="AccountException">
-
-            <wsdlsoap:fault name="AccountException" use="literal"/>
-
-         </wsdl:fault>
 
       </wsdl:operation>
 

Modified: beehive/trunk/system-controls/test/webservice/webapp/wsdl/pojotypes/ComplexTypesDocLitWrapped.wsdl
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/test/webservice/webapp/wsdl/pojotypes/ComplexTypesDocLitWrapped.wsdl?rev=369564&r1=369563&r2=369564&view=diff
==============================================================================
--- beehive/trunk/system-controls/test/webservice/webapp/wsdl/pojotypes/ComplexTypesDocLitWrapped.wsdl (original)
+++ beehive/trunk/system-controls/test/webservice/webapp/wsdl/pojotypes/ComplexTypesDocLitWrapped.wsdl Mon Jan 16 12:29:41 2006
@@ -52,10 +52,6 @@
      </sequence>
     </complexType>
    </element>
-   <complexType name="AccountException">
-    <sequence/>
-   </complexType>
-   <element name="fault" type="impl:AccountException"/>
    <element name="throwComplexAccountException">
     <complexType/>
    </element>
@@ -72,7 +68,7 @@
      <element name="msg2" nillable="true" type="xsd:string"/>
     </sequence>
    </complexType>
-   <element name="fault1" type="impl:ComplexAccountException"/>
+   <element name="fault" type="impl:ComplexAccountException"/>
   </schema>
  </wsdl:types>
 
@@ -84,7 +80,7 @@
 
    <wsdl:message name="ComplexAccountException">
 
-      <wsdl:part element="impl:fault1" name="fault"/>
+      <wsdl:part element="impl:fault" name="fault"/>
 
    </wsdl:message>
 
@@ -100,12 +96,6 @@
 
    </wsdl:message>
 
-   <wsdl:message name="AccountException">
-
-      <wsdl:part element="impl:fault" name="fault"/>
-
-   </wsdl:message>
-
    <wsdl:message name="throwAccountExceptionResponse">
 
       <wsdl:part element="impl:throwAccountExceptionResponse" name="parameters"/>
@@ -140,8 +130,6 @@
 
          <wsdl:output message="impl:throwAccountExceptionResponse" name="throwAccountExceptionResponse"/>
 
-         <wsdl:fault message="impl:AccountException" name="AccountException"/>
-
       </wsdl:operation>
 
       <wsdl:operation name="throwComplexAccountException">
@@ -193,12 +181,6 @@
             <wsdlsoap:body use="literal"/>
 
          </wsdl:output>
-
-         <wsdl:fault name="AccountException">
-
-            <wsdlsoap:fault name="AccountException" use="literal"/>
-
-         </wsdl:fault>
 
       </wsdl:operation>
 

Modified: beehive/trunk/system-controls/test/webservice/webapp/wsdl/pojotypes/ComplexTypesRpcLit.wsdl
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/test/webservice/webapp/wsdl/pojotypes/ComplexTypesRpcLit.wsdl?rev=369564&r1=369563&r2=369564&view=diff
==============================================================================
--- beehive/trunk/system-controls/test/webservice/webapp/wsdl/pojotypes/ComplexTypesRpcLit.wsdl (original)
+++ beehive/trunk/system-controls/test/webservice/webapp/wsdl/pojotypes/ComplexTypesRpcLit.wsdl Mon Jan 16 12:29:41 2006
@@ -25,9 +25,6 @@
      <element name="transactions" nillable="true" type="impl:ArrayOfAccountTransaction"/>
     </sequence>
    </complexType>
-   <complexType name="AccountException">
-    <sequence/>
-   </complexType>
    <complexType name="ComplexAccountException">
     <sequence>
      <element name="msg1" nillable="true" type="xsd:string"/>
@@ -77,12 +74,6 @@
 
    </wsdl:message>
 
-   <wsdl:message name="AccountException">
-
-      <wsdl:part name="fault" type="impl:AccountException"/>
-
-   </wsdl:message>
-
    <wsdl:portType name="ComplexTypesRpcLit">
 
       <wsdl:operation name="echoAccount" parameterOrder="account">
@@ -99,8 +90,6 @@
 
          <wsdl:output message="impl:throwAccountExceptionResponse" name="throwAccountExceptionResponse"/>
 
-         <wsdl:fault message="impl:AccountException" name="AccountException"/>
-
       </wsdl:operation>
 
       <wsdl:operation name="throwComplexAccountException">
@@ -152,12 +141,6 @@
             <wsdlsoap:body namespace="http://pojo.rpclit.complextypes" use="literal"/>
 
          </wsdl:output>
-
-         <wsdl:fault name="AccountException">
-
-            <wsdlsoap:fault name="AccountException" use="literal"/>
-
-         </wsdl:fault>
 
       </wsdl:operation>
 

Modified: beehive/trunk/system-controls/test/webservice/webapp/wsdl/xmlbeangen/ComplexTypesDocLitWrappedXmlbeangen.wsdl
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/test/webservice/webapp/wsdl/xmlbeangen/ComplexTypesDocLitWrappedXmlbeangen.wsdl?rev=369564&r1=369563&r2=369564&view=diff
==============================================================================
--- beehive/trunk/system-controls/test/webservice/webapp/wsdl/xmlbeangen/ComplexTypesDocLitWrappedXmlbeangen.wsdl (original)
+++ beehive/trunk/system-controls/test/webservice/webapp/wsdl/xmlbeangen/ComplexTypesDocLitWrappedXmlbeangen.wsdl Mon Jan 16 12:29:41 2006
@@ -52,10 +52,6 @@
      </sequence>
     </complexType>
    </element>
-   <complexType name="AccountException">
-    <sequence/>
-   </complexType>
-   <element name="fault" type="impl:AccountException"/>
    <element name="throwComplexAccountException">
     <complexType/>
    </element>
@@ -72,16 +68,10 @@
      <element name="msg2" nillable="true" type="xsd:string"/>
     </sequence>
    </complexType>
-   <element name="fault1" type="impl:ComplexAccountException"/>
+   <element name="fault" type="impl:ComplexAccountException"/>
   </schema>
  </wsdl:types>
 
-   <wsdl:message name="AccountException">
-
-      <wsdl:part element="impl:fault" name="fault"/>
-
-   </wsdl:message>
-
    <wsdl:message name="echoAccountResponse">
 
       <wsdl:part element="impl:echoAccountResponse" name="parameters"/>
@@ -96,7 +86,7 @@
 
    <wsdl:message name="ComplexAccountException">
 
-      <wsdl:part element="impl:fault1" name="fault"/>
+      <wsdl:part element="impl:fault" name="fault"/>
 
    </wsdl:message>
 
@@ -140,8 +130,6 @@
 
          <wsdl:output message="impl:throwAccountExceptionResponse" name="throwAccountExceptionResponse"/>
 
-         <wsdl:fault message="impl:AccountException" name="AccountException"/>
-
       </wsdl:operation>
 
       <wsdl:operation name="throwComplexAccountException">
@@ -193,12 +181,6 @@
             <wsdlsoap:body use="literal"/>
 
          </wsdl:output>
-
-         <wsdl:fault name="AccountException">
-
-            <wsdlsoap:fault name="AccountException" use="literal"/>
-
-         </wsdl:fault>
 
       </wsdl:operation>
 

Modified: beehive/trunk/system-controls/test/webservice/webapp/wsdl/xmlbeangen/ComplexTypesRpcLitXmlbeangen.wsdl
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/test/webservice/webapp/wsdl/xmlbeangen/ComplexTypesRpcLitXmlbeangen.wsdl?rev=369564&r1=369563&r2=369564&view=diff
==============================================================================
--- beehive/trunk/system-controls/test/webservice/webapp/wsdl/xmlbeangen/ComplexTypesRpcLitXmlbeangen.wsdl (original)
+++ beehive/trunk/system-controls/test/webservice/webapp/wsdl/xmlbeangen/ComplexTypesRpcLitXmlbeangen.wsdl Mon Jan 16 12:29:41 2006
@@ -25,9 +25,6 @@
      <element name="transactions" nillable="true" type="impl:ArrayOfAccountTransaction"/>
     </sequence>
    </complexType>
-   <complexType name="AccountException">
-    <sequence/>
-   </complexType>
    <complexType name="ComplexAccountException">
     <sequence>
      <element name="msg1" nillable="true" type="xsd:string"/>
@@ -77,12 +74,6 @@
 
    </wsdl:message>
 
-   <wsdl:message name="AccountException">
-
-      <wsdl:part name="fault" type="impl:AccountException"/>
-
-   </wsdl:message>
-
    <wsdl:portType name="ComplexTypesRpcLitXmlbeangen">
 
       <wsdl:operation name="echoAccount" parameterOrder="account">
@@ -99,8 +90,6 @@
 
          <wsdl:output message="impl:throwAccountExceptionResponse" name="throwAccountExceptionResponse"/>
 
-         <wsdl:fault message="impl:AccountException" name="AccountException"/>
-
       </wsdl:operation>
 
       <wsdl:operation name="throwComplexAccountException">
@@ -152,12 +141,6 @@
             <wsdlsoap:body namespace="http://xmlbeangen.rpclit.complextypes" use="literal"/>
 
          </wsdl:output>
-
-         <wsdl:fault name="AccountException">
-
-            <wsdlsoap:fault name="AccountException" use="literal"/>
-
-         </wsdl:fault>
 
       </wsdl:operation>
--- beehive/trunk/system-controls/test/webservice/webapp/tests/org/apache/beehive/controls/system/webservice/units/doclitwrapped/pojo/FaultsDocLitWrappedTest.java (original)
+++ beehive/trunk/system-controls/test/webservice/webapp/tests/org/apache/beehive/controls/system/webservice/units/doclitwrapped/pojo/FaultsDocLitWrappedTest.java Mon Jan 16 12:29:41 2006
@@ -17,72 +17,59 @@
  */
 package org.apache.beehive.controls.system.webservice.units.doclitwrapped.pojo;
 
+import complextypes.doclitwrapped.pojo.ComplexAccountException;
 import junit.framework.Test;
 import junit.framework.TestSuite;
 import org.apache.beehive.controls.api.bean.Control;
 import org.apache.beehive.controls.test.junit.ControlTestCase;
-import org.apache.axis.AxisFault;
-import org.w3c.dom.Element;
-import org.w3c.dom.NodeList;
-import org.w3c.dom.Node;
+
+import java.rmi.RemoteException;
 
 /**
  * Tests for faults from a doc/lit/wrapped service.
  */
 public class FaultsDocLitWrappedTest
-    extends ControlTestCase {
+        extends ControlTestCase {
 
     @Control
     public pojotypetest.ComplexTypesDocLitWrappedService client;
 
     /**
      * Test fault handling.
      * @throws Exception
      */
     public void testThrowAccountException() throws Exception {
-        assertTrue(true);
-        // todo: fails - needs further investigation
-        /*
         try {
             client.throwAccountException(66);
-        } catch (Exception e) {
-            assertEquals("org.apache.beehive.complextypes.AccountException: AccountException; input value=\"66\"", e.getMessage());
+        }
+        catch (Exception e) {
+            assertTrue(e instanceof RemoteException);
+            assertTrue("org.apache.beehive.complextypes.AccountException: AccountException; input value=\"66\"".equals(e.getMessage()));
             return;
         }
         fail("Expected AccountException to be thrown!");
-        */
     }
 
     /**
      * Test complex exception/fault handling.
+     *
      * @throws Exception
      */
     public void testThrowComplexAccountException() throws Exception {
-        assertTrue(true);
-        // todo: fails - needs further investigation
-        /*
         try {
             client.throwComplexAccountException();
-        } catch (Exception e) {
-            assertTrue(e instanceof AxisFault);
-            Element[] el = ((AxisFault)e).getFaultDetails();
-            assertNotNull(el);
-
-            NodeList children = el[0].getChildNodes();
-            assertTrue(children.getLength() == 2);
-
-            Node child = children.item(0);
-            assertEquals("msg1", child.getLocalName());
-            assertEquals("FirstMessage", child.getFirstChild().getNodeValue());
-
-            child = children.item(1);
-            assertEquals("msg2", child.getLocalName());
-            assertEquals("SecondMessage", child.getFirstChild().getNodeValue());
-
-             return;
+        }
+        catch (Exception e) {
+            assertTrue(e instanceof RemoteException);
+            assertTrue(((RemoteException) e).detail instanceof ComplexAccountException);
+
+            ComplexAccountException cae = (ComplexAccountException) ((RemoteException) e).detail;
+            assertTrue("FirstMessage".equals(cae.getMsg1()));
+            assertTrue("SecondMessage".equals(cae.getMsg2()));
+            return;
         }
         fail("Expected ComplexAccountException to be thrown!");
-        */
     }
 
     public static Test suite() {
@@ -17,72 +17,59 @@
 
     /**
-     * Test fault handling.
+     * Test fault handling for a RemoteException.
+     *
      * @throws Exception
      */

Modified: beehive/trunk/system-controls/test/webservice/webapp/tests/org/apache/beehive/controls/system/webservice/units/doclitwrapped/xmlbeangen/FaultsDocLitWrappedXmlbeangenTest.java
URL: http://svn.apache.org/viewcvs/beehive/trunk/system-controls/test/webservice/webapp/tests/org/apache/beehive/controls/system/webservice/units/doclitwrapped/xmlbeangen/FaultsDocLitWrappedXmlbeangenTest.java?rev=369564&r1=369563&r2=369564&view=diff
==============================================================================